@@ -36,7 +36,7 @@
 
 /* Defines the poppler version. */
 #ifndef POPPLER_VERSION
-#define POPPLER_VERSION "25.11.0"
+#define POPPLER_VERSION "25.12.0"
 #endif
 
 /* Use single precision arithmetic in the Splash backend */
@@ -71,7 +71,7 @@
 
 /* Build against libpng. */
 #ifndef ENABLE_LIBPNG
-/* #undef ENABLE_LIBPNG */
+#define ENABLE_LIBPNG 1
 #endif
 
 /* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'.
